rqr
===

Python ReQuiRements.

WARNING: This is alpha and a pure prototype at the moment.

Installation
------------

.. code:: bash

    $ pip install rqr

Usage
-----

Call `rqr` and it will parse your requirement file, showing you possible updates.

.. code:: bash

    $ rqr

    django 1.9.3 -> 1.9.7
    djangorestframework 3.3.1 -> 3.3.3
    django-filemanager ok
    django-polymorphic 0.9.1 -> 0.9.2
    pillow 3.1.1 -> 3.3.0
